==> zither-1.1.16.tar.gz: zither_prj/apollon/menu4.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }
-->";
echo "</style>";

echo "</HEAD>";



echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// 顼긢 
echo "<h2 id='count'>";
echo "</h2>";
echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "顼긢";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";

echo "<a href='./monitor_manu.php?QUE_DATA=ERRCOMP' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";


echo "<FORM METHOD=GET ACTION='monitor_comp.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯǯ";
echo "<select size=1 name=YE>";
echo "<option value=>not";
echo "<option value=2006>2006";
echo "<option value=2007>2007";
echo "<option value=2008>2008";
echo "<option value=2009>2009";
echo "<option value=2010>2010";
echo "<option value=2011>2011";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=YE_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=MO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=DA>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "<option value=24>24";
echo "<option value=25>25";
echo "<option value=26>26";
echo "<option value=27>27";
echo "<option value=28>28";
echo "<option value=29>29";
echo "<option value=30>30";
echo "<option value=31>31";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=DA_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=HA>";
echo "<option value=>not";
echo "<option value=0>0";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "<option value=24>24";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=HA_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=MONITOR>";
echo "<option value=>NOT";
echo "<option value=PORT>PORT";
echo "<option value=COMAND>COMAND";
echo "<option value=SNMP>SNMP";
echo "<option value=CONNECT>CONNECT";
echo "<option value=CLOSE>CLOSE";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MONITOR_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץȥ";
echo "<select size=1 name=PROTO>";
echo "<option value=>̤";
print("<option value=ICMP>ICMP̳ǧ");
print("<option value=UDP>UDPݡ");
print("<option value=TCP>TCPݡ");
print("<option value=URL>URL status");
print("<option value=SMTP>SMTP status");
print("<option value=SNTP>NTPλ");
print("<option value=HOST>DNS̾");
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PROTO_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ݡֹ";
echo "<INPUT type='text' NAME=PORT size='12' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PORT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץ饤ƥ";
echo "<select size=1 name=PRINO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PRINO_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "Ψ";
echo "<select size=1 name=BY>";
echo "<option value=160>160";
echo "<option value=320 selected>320";
echo "<option value=640>640";
echo "<option value=1024>1024";
echo "</select>";
echo "</font>";
echo "</td>";
echo "</tr>";



echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";
echo "</form>";
echo "<br>";


echo "</center>";

?>

</BODY>
</HTML>

==> zither-1.1.22.tar.gz: zither_prj/apollon/menu4.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }
-->";
echo "</style>";

echo "</HEAD>";



echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// 顼긢 
echo "<h2 id='count'>";
echo "</h2>";
echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "顼긢";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";

echo "<a href='./monitor_manu.php?QUE_DATA=ERRCOMP' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";


echo "<FORM METHOD=GET ACTION='monitor_comp.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯǯ";
echo "<select size=1 name=YE>";
echo "<option value=>not";
echo "<option value=2006>2006";
echo "<option value=2007>2007";
echo "<option value=2008>2008";
echo "<option value=2009>2009";
echo "<option value=2010>2010";
echo "<option value=2011>2011";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=YE_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=MO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=DA>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "<option value=24>24";
echo "<option value=25>25";
echo "<option value=26>26";
echo "<option value=27>27";
echo "<option value=28>28";
echo "<option value=29>29";
echo "<option value=30>30";
echo "<option value=31>31";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=DA_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ȯ";
echo "<select size=1 name=HA>";
echo "<option value=>not";
echo "<option value=0>0";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "<option value=9>9";
echo "<option value=10>10";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "<option value=14>14";
echo "<option value=15>15";
echo "<option value=16>16";
echo "<option value=17>17";
echo "<option value=18>18";
echo "<option value=19>19";
echo "<option value=20>20";
echo "<option value=21>21";
echo "<option value=22>22";
echo "<option value=23>23";
echo "<option value=24>24";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=HA_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=MONITOR>";
echo "<option value=>NOT";
echo "<option value=PORT>PORT";
echo "<option value=COMAND>COMAND";
echo "<option value=SNMP>SNMP";
echo "<option value=CONNECT>CONNECT";
echo "<option value=CLOSE>CLOSE";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MONITOR_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץȥ";
echo "<select size=1 name=PROTO>";
echo "<option value=>̤";
print("<option value=ICMP>ICMP̳ǧ");
print("<option value=UDP>UDPݡ");
print("<option value=TCP>TCPݡ");
print("<option value=URL>URL status");
print("<option value=SMTP>SMTP status");
print("<option value=FTP>FTP status");
print("<option value=POP>POP status");
print("<option value=SSH>SSH status");
print("<option value=SNTP>NTPλ");
print("<option value=HOST>DNS̾");
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PROTO_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ݡֹ";
echo "<INPUT type='text' NAME=PORT size='12' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PORT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץ饤ƥ";
echo "<select size=1 name=PRINO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PRINO_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "Ψ";
echo "<select size=1 name=BY>";
echo "<option value=160>160";
echo "<option value=320 selected>320";
echo "<option value=640>640";
echo "<option value=1024>1024";
echo "</select>";
echo "</font>";
echo "</td>";
echo "</tr>";



echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";
echo "</form>";
echo "<br>";


echo "</center>";

?>

</BODY>
</HTML>
